@@ -40,28 +40,16 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtkcheckbutton.h>
 #include <gtk/gtkcheckmenuitem.h>
+#include <gtk/gtkstatusicon.h>
 #include <gtk/gtkstock.h>
 #include <gtk/gtktooltips.h>
 #include <gtk/gtkversion.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <libgnome/gnome-exec.h>
 #include <libgnome/gnome-sound.h>
 #include <libgnomeui/gnome-dialog-util.h>
 #include <libgnomeui/gnome-uidefs.h>
 
-#if GTK_CHECK_VERSION (2, 9, 0)
-#include <gtk/gtkstatusicon.h>
-#else
-#include <e-util/eggtrayicon.h>
-#endif
-
-/* Evo's copy of eggtrayicon, for Win32, contains the gtkstatusicon
- * API.
- */
-#if GTK_CHECK_VERSION (2, 9, 0) || defined (GDK_WINDOWING_WIN32)
-#define USE_GTK_STATUS_ICON
-#endif
-
 #include <e-util/e-icon-factory.h>
 #include <libecal/e-cal-time-util.h>
 #include <libecal/e-cal-component.h>
@@ -104,13 +92,7 @@ static GHashTable *client_alarms_hash = NULL;
 static GList *tray_icons_list = NULL;
 
 /* Top Tray Image */
-#ifndef USE_GTK_STATUS_ICON
-static GtkWidget *tray_icon = NULL;
-static GtkWidget *tray_image = NULL;
-static GtkWidget *tray_event_box = NULL;
-#else
 static GtkStatusIcon *tray_icon = NULL;
-#endif
 static int tray_blink_id = -1;
 static int tray_blink_state = FALSE;
 static AlarmNotify *an;
@@ -939,13 +921,8 @@ typedef struct {
 	ECalComponent *comp;
 	ECal *client;
 	ECalView *query;
-#ifndef USE_GTK_STATUS_ICON
-	GtkWidget *tray_icon;
-	GtkWidget *image;
-#else
         GtkStatusIcon *tray_icon;
 	GdkPixbuf *image;
-#endif
 	GtkTreeIter iter;
 } TrayIconData;
 
@@ -1082,8 +1059,10 @@ tray_list_remove_cqa_async(EThread *e, AlarmMsg *msg, void *data)
 		} else {
 			GtkTreeIter iter;
 			GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (alarm_notifications_dialog->treeview));
+			GtkTreeSelection *sel;
+
 			gtk_tree_model_get_iter_first (model, &iter);
-			GtkTreeSelection *sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (alarm_notifications_dialog->treeview));
+			sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (alarm_notifications_dialog->treeview));
 			gtk_tree_selection_select_iter (sel, &iter);
 		}
 	}
@@ -1280,12 +1259,7 @@ open_alarm_dialog (TrayIconData *tray_data)
 			g_source_remove (tray_blink_id);
 		tray_blink_id = -1;
 
-#ifndef USE_GTK_STATUS_ICON
-		gtk_widget_destroy (GTK_WIDGET (tray_icon));			
-		tray_image = NULL;
-#else
 		g_object_unref (tray_icon);
-#endif
 		tray_icon = NULL;
 
 		if (!alarm_notifications_dialog)
@@ -1338,12 +1312,8 @@ tray_icon_clicked_cb (GtkWidget *widget, GdkEventButton *event, gpointer user_da
 			
 			
 
-#ifndef USE_GTK_STATUS_ICON
-			gtk_widget_destroy (GTK_WIDGET (tray_icon));			
-			tray_image = NULL;
-#else
+			gtk_status_icon_set_visible (tray_icon, FALSE);
 			g_object_unref (tray_icon);
-#endif
 			tray_icon = NULL;			
 			return TRUE;
 		}
@@ -1352,7 +1322,6 @@ tray_icon_clicked_cb (GtkWidget *widget, GdkEventButton *event, gpointer user_da
 	return FALSE;
 }
 
-#ifdef USE_GTK_STATUS_ICON
 static void
 icon_activated (GtkStatusIcon *icon)
 {
@@ -1364,7 +1333,21 @@ icon_activated (GtkStatusIcon *icon)
 
   tray_icon_clicked_cb (NULL, &event, NULL);
 }
-#endif
+
+static void
+popup_menu (GtkStatusIcon *icon, guint button, guint activate_time)
+{
+	if (button == 3) {
+		/* right click */
+		GdkEventButton event;
+
+		event.type = GDK_BUTTON_PRESS;
+		event.button = 3;
+		event.time = gtk_get_current_event_time ();
+
+		tray_icon_clicked_cb (NULL, &event, NULL);
+	}
+}
 
 static gboolean
 tray_icon_blink_cb (gpointer data)
@@ -1378,13 +1361,8 @@ tray_icon_blink_cb (gpointer data)
 					   "stock_appointment-reminder",
 					   E_ICON_SIZE_LARGE_TOOLBAR);
 
-#ifndef USE_GTK_STATUS_ICON
-	if (tray_icon && tray_image)
-		gtk_image_set_from_pixbuf (GTK_IMAGE (tray_image), pixbuf);
-#else
 	if (tray_icon)
 		gtk_status_icon_set_from_pixbuf (tray_icon, pixbuf);
-#endif
 	g_object_unref (pixbuf);
 
 	return TRUE;
@@ -1427,10 +1405,6 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	QueuedAlarm *qa;
 	ECalComponent *comp;
 	const char *summary, *description, *location;
-#ifndef USE_GTK_STATUS_ICON
-	GtkWidget *image=NULL;
-	GtkTooltips *tooltips;
-#endif
 	TrayIconData *tray_data;
 	ECalComponentText text;
 	GSList *text_list;
@@ -1474,27 +1448,15 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	        location = _("No location information available.");
 
 	/* create the tray icon */
-#ifndef USE_GTK_STATUS_ICON
-	if (tray_icon == NULL) {
-		tray_icon = GTK_WIDGET (egg_tray_icon_new ("Evolution Alarm"));
-		tray_image = e_icon_factory_get_image  ("stock_appointment-reminder", E_ICON_SIZE_LARGE_TOOLBAR);
-		tray_event_box = gtk_event_box_new ();
-		gtk_container_add (GTK_CONTAINER (tray_event_box), tray_image);
-		gtk_container_add (GTK_CONTAINER (tray_icon), tray_event_box);
-		g_signal_connect (G_OBJECT (tray_event_box), "button_press_event",
-				  G_CALLBACK (tray_icon_clicked_cb), NULL);
-		gtk_widget_show_all (tray_icon);
-	}
-	tooltips = gtk_tooltips_new ();
-	
-#else
 	if (tray_icon == NULL) {
 		tray_icon = gtk_status_icon_new ();
 		gtk_status_icon_set_from_pixbuf (tray_icon, e_icon_factory_get_icon ("stock_appointment-reminder", E_ICON_SIZE_LARGE_TOOLBAR));
 		g_signal_connect (G_OBJECT (tray_icon), "activate",
 				  G_CALLBACK (icon_activated), NULL);
+		g_signal_connect (G_OBJECT (tray_icon), "popup-menu",
+				  G_CALLBACK (popup_menu), NULL);
+
 	}
-#endif
 	
 	current_zone = config_data_get_timezone ();
 	alarm_str = timet_to_str_with_zone (trigger, current_zone);
@@ -1516,9 +1478,6 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	tray_data->comp = g_object_ref (e_cal_component_clone (comp));
 	tray_data->client = cqa->parent_client->client;
 	tray_data->query = g_object_ref (cqa->parent_client->query);
-#ifndef USE_GTK_STATUS_ICON
-	tray_data->image = image;
-#endif
 	tray_data->blink_state = FALSE;
 	tray_data->snooze_set = FALSE;
 	g_object_ref (tray_data->client);
@@ -1531,19 +1490,10 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 		char *tip;
 
 		tip =  g_strdup_printf (_("You have %d alarms"), g_list_length (tray_icons_list));
-#ifndef USE_GTK_STATUS_ICON
-		gtk_tooltips_set_tip (GTK_TOOLTIPS (tooltips), tray_event_box, tip, NULL);
-		g_free (tip);
-#else
 		gtk_status_icon_set_tooltip (tray_icon, tip);
-#endif
 	}
 	else {
-#ifndef USE_GTK_STATUS_ICON
-		gtk_tooltips_set_tip (GTK_TOOLTIPS (tooltips), tray_event_box, str, NULL);
-#else
 		gtk_status_icon_set_tooltip (tray_icon, str);
-#endif
 	}
 
 	g_free (start_str);
@@ -1579,6 +1529,7 @@ popup_notification (time_t trigger, CompQueuedAlarms *cqa,
 	char *str, *start_str, *end_str, *alarm_str, *time_str;
 	icaltimezone *current_zone;
 	ECalComponentOrganizer organiser;
+	NotifyNotification *n;
 	char *body;
 
 	d(printf("%s:%d (popup_notification)\n",__FILE__, __LINE__));
@@ -1627,7 +1578,7 @@ popup_notification (time_t trigger, CompQueuedAlarms *cqa,
 			body = g_strdup_printf ("%s %s", start_str, time_str);			
 	}
 
-	NotifyNotification *n = notify_notification_new (summary, body, "stock_appointment-reminder", NULL);
+	n = notify_notification_new (summary, body, "stock_appointment-reminder", NULL);
 	if (!notify_notification_show(n, NULL))
 	    g_warning ("Could not send notification to daemon\n");	
 
@@ -1696,6 +1647,10 @@ mail_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id)
 
 	d(printf("%s:%d (mail_notification)\n",__FILE__, __LINE__));
 	
+	if (!e_cal_get_static_capability (cqa->parent_client->client,
+						CAL_STATIC_CAPABILITY_NO_EMAIL_ALARMS))
+		return;
+
 	dialog = gtk_dialog_new_with_buttons (_("Warning"),
 					      NULL, 0,
 					      GTK_STOCK_OK, GTK_RESPONSE_CANCEL,
