@@ -24,7 +24,7 @@
 
 #include <string.h>
 #include <glib/garray.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 #include <libedataserver/e-time-utils.h>
 #include <libecal/e-cal-time-util.h>
 #include "comp-util.h"
@@ -947,7 +947,7 @@ static const char *
 ecm_get_color_for_component (ECalModel *model, ECalModelComponent *comp_data)
 {
 	ESource *source;
-	guint32 source_color;
+	const gchar *color_spec;
 	gint i, first_empty = 0;
 	static AssignedColorData assigned_colors[] = {
 		{ "#BECEDD", NULL }, /* 190 206 221     Blue */
@@ -965,9 +965,10 @@ ecm_get_color_for_component (ECalModel *model, ECalModelComponent *comp_data)
 	g_return_val_if_fail (E_IS_CAL_MODEL (model), NULL);
 
 	source = e_cal_get_source (comp_data->client);
-	if (e_source_get_color (source, &source_color)) {
+	color_spec = e_source_peek_color_spec (source);
+	if (color_spec != NULL) {
 		g_free (comp_data->color);
-		comp_data->color = g_strdup_printf ("#%06x", source_color & 0xffffff);
+		comp_data->color = g_strdup (color_spec);
 		return comp_data->color;
 	}
                                                                    
@@ -1810,6 +1811,37 @@ e_cal_model_set_search_query (ECalModel *model, const char *sexp)
 	redo_queries (model);
 }
 
+/**
+ * e_cal_model_set_query
+ */
+void
+e_cal_model_set_search_query_with_time_range (ECalModel *model, const char *sexp, time_t start, time_t end)
+{
+	ECalModelPrivate *priv;
+	gboolean do_query = FALSE;
+
+	g_return_if_fail (E_IS_CAL_MODEL (model));
+
+	priv = model->priv;
+
+	if (strcmp (sexp ? sexp : "", priv->search_sexp ? priv->search_sexp : "")) {
+		if (priv->search_sexp)
+			g_free (priv->search_sexp);
+
+		priv->search_sexp = g_strdup (sexp);
+		do_query = TRUE;
+	}
+		
+	if (!(priv->start == start && priv->end == end)) {
+		priv->start = start;
+		priv->end = end;
+		do_query = TRUE;
+	}
+
+	if (do_query)
+		redo_queries (model);
+}
+
 /**
  * e_cal_model_create_component_with_defaults
  */
@@ -2101,17 +2133,30 @@ void
 e_cal_model_set_instance_times (ECalModelComponent *comp_data, const icaltimezone *zone)
 {
 	struct icaltimetype start_time, end_time;
+	icalcomponent_kind kind;
 
+	kind = icalcomponent_isa (comp_data->icalcomp);
 	start_time = icalcomponent_get_dtstart (comp_data->icalcomp);
 	end_time = icalcomponent_get_dtend (comp_data->icalcomp);
 
-	if (start_time.is_date && end_time.is_date && (icaltime_compare_date_only (start_time, end_time) == 0)) {
-		/* If both DTSTART and DTEND are DATE values, and they are the
-		   same day, we add 1 day to DTEND. This means that most
-		   events created with the old Evolution behavior will still
-		   work OK. */
-		icaltime_adjust (&end_time, 1, 0, 0, 0);
-		icalcomponent_set_dtend (comp_data->icalcomp, end_time);
+	if (kind == ICAL_VEVENT_COMPONENT) {
+		if (start_time.is_date && icaltime_is_null_time (end_time)) {
+			/* If end_time is null and it's an all day event,
+			 * just make start_time = end_time so that end_time
+			 * will be a valid date
+			 */
+			end_time = start_time;
+			icaltime_adjust (&end_time, 1, 0, 0, 0);
+			icalcomponent_set_dtend (comp_data->icalcomp, end_time);
+		} else if (start_time.is_date && end_time.is_date &&
+			   (icaltime_compare_date_only (start_time, end_time) == 0)) {
+			/* If both DTSTART and DTEND are DATE values, and they are the
+			   same day, we add 1 day to DTEND. This means that most
+			   events created with the old Evolution behavior will still
+			   work OK. */
+			icaltime_adjust (&end_time, 1, 0, 0, 0);
+			icalcomponent_set_dtend (comp_data->icalcomp, end_time);
+		}
 	}
 
 	if (start_time.zone)
