@@ -29,7 +29,7 @@
 
 #include <libedataserver/e-data-server-util.h>
 #include <e-util/e-util.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include "mail-mt.h"
 #include "mail-ops.h"
@@ -256,6 +256,8 @@ composer_get_message (EMsgComposer *composer, gboolean save_html_object_data)
 	EAccount *account;
 	int i;
 	GList *postlist;
+	EMEvent *eme;
+	EMEventTargetMessage *target;
 	
 	gconf = mail_config_get_gconf_client ();
 	
@@ -355,11 +357,28 @@ composer_get_message (EMsgComposer *composer, gboolean save_html_object_data)
 			goto finished;
 	}
 	
+	/** @Event: composer.presendchecks
+	 * @Title: Composer PreSend Checks
+	 * @Target: EMEventTargetMessage
+	 * 
+	 * composer.presendchecks is emitted during pre-checks for the message just before sending.
+	 * Since the e-plugin framework doesn't provide a way to return a value from the plugin, 
+	 * use 'presend_check_status' to set whether the check passed / failed.
+	 */
+	eme = em_event_peek();
+	target = em_event_target_new_composer (eme, composer, 0);
+	g_object_set_data (composer, "presend_check_status", GINT_TO_POINTER(0));
+
+	e_event_emit((EEvent *)eme, "composer.presendchecks", (EEventTarget *)target);
+
+	if (GPOINTER_TO_INT (g_object_get_data (composer, "presend_check_status")))
+		goto finished;
+
 	/* actually get the message now, this will sign/encrypt etc */
 	message = e_msg_composer_get_message (composer, save_html_object_data);
 	if (message == NULL)
 		goto finished;
-	
+       
 	/* Add info about the sending account */
 	account = e_msg_composer_get_preferred_account (composer);
 	
@@ -371,7 +390,7 @@ composer_get_message (EMsgComposer *composer, gboolean save_html_object_data)
 		if (account->id->organization && *account->id->organization) {
 			char *org;
 			
-			org = camel_header_encode_string (account->id->organization);
+			org = camel_header_encode_string ((const unsigned char *)account->id->organization);
 			camel_medium_set_header (CAMEL_MEDIUM (message), "Organization", org);
 			g_free (org);
 		}
@@ -1121,7 +1140,7 @@ em_utils_handle_receipt (CamelFolder *folder, const char *uid, CamelMimeMessage
 		return;
 	}
 
-	if ( (addr = camel_medium_get_header((CamelMedium *)msg, "Disposition-Notification-To")) == NULL) {
+	if ((addr = camel_medium_get_header((CamelMedium *)msg, "Disposition-Notification-To")) == NULL) {
 		camel_message_info_free(info);
 		return;
 	}
@@ -1139,9 +1158,8 @@ em_utils_handle_receipt (CamelFolder *folder, const char *uid, CamelMimeMessage
 			addr++;
 	}
 	
-	if (account && account->receipt_policy == E_ACCOUNT_RECEIPT_ALWAYS
-	    || (account->receipt_policy == E_ACCOUNT_RECEIPT_ASK
-		&& e_error_run (NULL, "mail:ask-receipt", addr, camel_mime_message_get_subject(msg)) == GTK_RESPONSE_YES))
+	if (account && (account->receipt_policy == E_ACCOUNT_RECEIPT_ALWAYS || account->receipt_policy == E_ACCOUNT_RECEIPT_ASK)
+	    && e_error_run (NULL, "mail:ask-receipt", addr, camel_mime_message_get_subject(msg)) == GTK_RESPONSE_YES)
 		em_utils_send_receipt(folder, msg);
 }
 
@@ -1265,6 +1283,14 @@ em_utils_send_receipt (CamelFolder *folder, CamelMimeMessage *message)
 	camel_object_unref (addr);
 
 	camel_medium_set_header (CAMEL_MEDIUM (receipt), "Return-Path", "<>");
+	if(account) {
+		camel_medium_set_header (CAMEL_MEDIUM (receipt), 
+					"X-Evolution-Account", account->uid);
+		camel_medium_set_header (CAMEL_MEDIUM (receipt), 
+					"X-Evolution-Transport", account->transport->url);
+		camel_medium_set_header (CAMEL_MEDIUM (receipt), 
+					"X-Evolution-Fcc",  account->sent_folder_uri);
+	}
 
 	/* Send the receipt */
 	out_folder = mail_component_get_folder(NULL, MAIL_COMPONENT_FOLDER_OUTBOX);
@@ -1850,6 +1876,12 @@ composer_set_body (EMsgComposer *composer, CamelMimeMessage *message, EMFormat *
 		e_msg_composer_attach (composer, part);
 		camel_object_unref (part);
 		break;
+	case MAIL_CONFIG_REPLY_OUTLOOK:
+		text = em_utils_message_to_html(message, _("-----Original Message-----"), EM_FORMAT_QUOTE_HEADERS, &len, source);
+		e_msg_composer_set_body_text(composer, text, len);
+		g_free (text);
+		break;
+
 	case MAIL_CONFIG_REPLY_QUOTED:
 	default:
 		/* do what any sane user would want when replying... */
