@@ -78,6 +78,7 @@
 #include <camel/camel-store.h>
 
 #include "e-util/e-dialog-utils.h"
+#include "e-util/e-util.h"
 #include "e-util/e-error.h"
 #include "e-util/e-util-private.h"
 #include "em-utils.h"
@@ -258,32 +259,6 @@ free_one_ui_file (gpointer data,
 	g_free (data);
 }
 
-static char *
-string_without_underscores (const char *s)
-{
-	char *new_string;
-	const char *sp;
-	char *dp;
-
-	new_string = g_malloc (strlen (s) + 1);
-
-	dp = new_string;
-	for (sp = s; *sp != '\0'; sp ++) {
-		if (*sp != '_') {
-			*dp = *sp;
-			dp ++;
-		} else if (sp[1] == '_') {
-			/* Translate "__" in "_".  */
-			*dp = '_';
-			dp ++;
-			sp ++;
-		}
-	}
-	*dp = 0;
-
-	return new_string;
-}
-
 static GtkWidget *
 generate_viewoption_menu (GtkWidget *emfv)
 {
@@ -296,7 +271,7 @@ generate_viewoption_menu (GtkWidget *emfv)
 	for (i = 0; emfb_view_items[i].search.id != -1; ++i) {
 		if (emfb_view_items[i].search.text) {
 			char *str;
-			str = string_without_underscores (_(emfb_view_items[i].search.text));
+			str = e_str_without_underscores (_(emfb_view_items[i].search.text));
 			menu_item = gtk_image_menu_item_new_with_label (str);
  			if (emfb_view_items[i].image)
  				gtk_image_menu_item_set_image ((GtkImageMenuItem *)menu_item, e_icon_factory_get_image (emfb_view_items[i].image, E_ICON_SIZE_MENU)); 
@@ -333,7 +308,7 @@ generate_viewoption_menu (GtkWidget *emfv)
 			g_object_unref(gc); 
 			
 			image = gtk_image_new_from_pixmap(pixmap, NULL); 
-			str = string_without_underscores (label->name);
+			str = e_str_without_underscores (label->name);
 			menu_item = gtk_image_menu_item_new_with_label (str);
 			g_free (str);
 			gtk_image_menu_item_set_image ((GtkImageMenuItem *)menu_item, image); 
@@ -351,7 +326,7 @@ generate_viewoption_menu (GtkWidget *emfv)
 	for (i = 0; temp_view_items[i].search.id != -1; ++i) {
 		if (temp_view_items[i].search.text) {
 			char *str;
-			str = string_without_underscores (_(temp_view_items[i].search.text));
+			str = e_str_without_underscores (_(temp_view_items[i].search.text));
 			menu_item = gtk_image_menu_item_new_with_label (str);
 			if (temp_view_items[i].image)
 				gtk_image_menu_item_set_image ((GtkImageMenuItem *)menu_item, e_icon_factory_get_image (temp_view_items[i].image, E_ICON_SIZE_MENU)); 
@@ -411,6 +386,25 @@ emfb_realize (GtkWidget *widget)
 	e_search_bar_set_viewoption_menu ((ESearchBar *)emfb->search, menu);	
 }
 	      
+static void
+html_scroll (GtkHTML *html,
+	GtkOrientation orientation,
+	GtkScrollType  scroll_type,
+	gfloat         position,
+	EMFolderBrowser *emfb)
+
+{
+	if (html->binding_handled || orientation != GTK_ORIENTATION_VERTICAL)
+		return;
+
+	if (scroll_type == GTK_SCROLL_PAGE_FORWARD) {
+		gtk_widget_grab_focus ((GtkWidget *)((EMFolderView *) emfb)->list);
+		message_list_select(((EMFolderView *) emfb)->list, MESSAGE_LIST_SELECT_NEXT, 0, CAMEL_MESSAGE_SEEN);		
+	} else if (scroll_type == GTK_SCROLL_PAGE_BACKWARD) {
+		gtk_widget_grab_focus ((GtkWidget *)((EMFolderView *) emfb)->list);
+		message_list_select(((EMFolderView *) emfb)->list, MESSAGE_LIST_SELECT_NEXT, 0, CAMEL_MESSAGE_SEEN);		
+	}
+}
 static void
 emfb_init(GObject *o)
 {
@@ -423,6 +417,8 @@ emfb_init(GObject *o)
 	emfb->view.preview_active = TRUE;
 	emfb->view.list_active = TRUE;
 
+	g_signal_connect_after (((EMFormatHTML *)(emfb->view.preview))->html, "scroll", G_CALLBACK (html_scroll), emfb);
+
 	g_slist_foreach (emfb->view.ui_files, free_one_ui_file, NULL);
 	g_slist_free(emfb->view.ui_files);
 
@@ -1170,20 +1166,36 @@ emfb_search_search_cleared(ESearchBar *esb)
 static int
 emfb_list_key_press(ETree *tree, int row, ETreePath path, int col, GdkEvent *ev, EMFolderBrowser *emfb)
 {
+	gboolean state, folder_choose = TRUE;
 	if ((ev->key.state & GDK_CONTROL_MASK) != 0)
 		return FALSE;
 	
 	switch (ev->key.keyval) {
 	case GDK_space:
-		em_utils_adjustment_page(gtk_scrolled_window_get_vadjustment((GtkScrolledWindow *)emfb->priv->scroll), TRUE);
+		if (!emfb->view.preview->caret_mode) {
+			state = gtk_html_command(((EMFormatHTML *)((EMFolderView *) emfb)->preview)->html, "scroll-forward");
+			if (!state)
+				folder_choose = message_list_select(((EMFolderView *) emfb)->list, MESSAGE_LIST_SELECT_NEXT, 0, CAMEL_MESSAGE_SEEN);
+		} else 
+			em_utils_adjustment_page(gtk_scrolled_window_get_vadjustment((GtkScrolledWindow *)emfb->priv->scroll), TRUE);
 		break;
 	case GDK_BackSpace:
-		em_utils_adjustment_page(gtk_scrolled_window_get_vadjustment((GtkScrolledWindow *)emfb->priv->scroll), FALSE);
+		if (!emfb->view.preview->caret_mode) {
+			state = gtk_html_command(((EMFormatHTML *)((EMFolderView *) emfb)->preview)->html, "scroll-backward");
+			if (!state)
+				folder_choose = message_list_select(((EMFolderView *) emfb)->list, MESSAGE_LIST_SELECT_PREVIOUS, 0, CAMEL_MESSAGE_SEEN);
+		} else
+			em_utils_adjustment_page(gtk_scrolled_window_get_vadjustment((GtkScrolledWindow *)emfb->priv->scroll), FALSE);
 		break;
 	default:
 		return FALSE;
 	}
 	
+	if (!folder_choose && !emfb->view.preview->caret_mode) {
+		EMFolderTree *emft = g_object_get_data((GObject*)emfb, "foldertree");
+		em_folder_tree_select_next_path (emft);
+		gtk_widget_grab_focus ((GtkWidget *)((EMFolderView *) emfb)->list);
+	}
 	return TRUE;
 }
 
