@@ -67,7 +67,7 @@
 #include <glade/glade.h>
 
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
-#include <libgnome/gnome-i18n.h>
+#include <glib/gi18n.h>
 
 #include <bonobo/bonobo-control-frame.h>
 #include <bonobo/bonobo-stream-memory.h>
@@ -475,7 +475,7 @@ void em_format_html_display_set_caret_mode(EMFormatHTMLDisplay *efhd, gboolean s
 EAttachmentBar *
 em_format_html_display_get_bar (EMFormatHTMLDisplay *efhd)
 {
-	return efhd->priv->attachment_bar;
+	return E_ATTACHMENT_BAR (efhd->priv->attachment_bar);
 }
 
 void
@@ -628,16 +628,16 @@ clear_button_clicked_cb (GtkWidget *widget, gpointer dummy, EMFormatHTMLDisplay
 {
 	struct _EMFormatHTMLDisplayPrivate *p = efhd->priv;
 
-	gtk_entry_set_text (p->search_entry, "");
+	gtk_entry_set_text (GTK_ENTRY (p->search_entry), "");
 
-	gtk_signal_emit_by_name (p->search_entry, "activate", efhd);
+	gtk_signal_emit_by_name (GTK_OBJECT (p->search_entry), "activate", efhd);
 }
 
 /* Controlls the visibility of icon_entry's visibility */
 static void
 icon_entry_changed_cb (GtkWidget *widget, GtkWidget *clear_button)
 {
-	const char *text = gtk_entry_get_text (widget);
+	const char *text = gtk_entry_get_text (GTK_ENTRY (widget));
 
 	if (text && *text)
 		gtk_widget_show (clear_button);
@@ -649,7 +649,7 @@ GtkWidget *
 em_format_html_get_search_dialog (EMFormatHTMLDisplay *efhd)
 {
 	struct _EMFormatHTMLDisplayPrivate *p = efhd->priv;
-	GtkWidget *hbox3, *hbox2, *button3, *button2, *button1, *label1, *alignment, *image1, *label2;
+	GtkWidget *hbox2, *button3, *button2, *label1;
 	GtkWidget *icon_entry, *clear_button;
 
 	p->search_entry_box = gtk_hbox_new (FALSE, 0);
@@ -661,15 +661,15 @@ em_format_html_get_search_dialog (EMFormatHTMLDisplay *efhd)
 	/* Icon entry */
 	icon_entry = e_icon_entry_new ();
 	p->search_entry = e_icon_entry_get_entry (E_ICON_ENTRY (icon_entry));
-	gtk_label_set_mnemonic_widget (label1, p->search_entry);
+	gtk_label_set_mnemonic_widget (GTK_LABEL (label1), p->search_entry);
 	gtk_widget_show (p->search_entry);
 	clear_button = e_icon_entry_create_button ("gtk-clear");
 	e_icon_entry_pack_widget (E_ICON_ENTRY (icon_entry), clear_button, FALSE);
 	gtk_widget_show_all (icon_entry);
 	gtk_widget_hide (clear_button);
 
-	g_signal_connect (G_OBJECT (clear_button), "button-press-event", clear_button_clicked_cb, efhd);
-	g_signal_connect (G_OBJECT (p->search_entry), "changed", icon_entry_changed_cb, clear_button);
+	g_signal_connect (G_OBJECT (clear_button), "button-press-event", (GCallback) clear_button_clicked_cb, efhd);
+	g_signal_connect (G_OBJECT (p->search_entry), "changed", (GCallback) icon_entry_changed_cb, clear_button);
 
 	gtk_box_pack_start ((GtkBox *)(p->search_entry_box), icon_entry, FALSE, FALSE, 0);
 //	gtk_box_pack_start ((GtkBox *)(p->search_entry_box), icon_entry, TRUE, TRUE, 0);
@@ -679,23 +679,23 @@ em_format_html_get_search_dialog (EMFormatHTMLDisplay *efhd)
 //	gtk_box_pack_start ((GtkBox *)(hbox2), p->search_entry_box, TRUE, TRUE, 5);
 
 	button3 = gtk_button_new_with_mnemonic (_("_Previous"));
-	gtk_button_set_image (button3, gtk_image_new_from_stock(GTK_STOCK_GO_BACK, GTK_ICON_SIZE_BUTTON));
+	gtk_button_set_image (GTK_BUTTON (button3), GTK_WIDGET(gtk_image_new_from_stock(GTK_STOCK_GO_BACK, GTK_ICON_SIZE_BUTTON)));
 	gtk_widget_show (button3);
-	gtk_box_pack_start ((GtkBox *)(hbox2), button3, FALSE, FALSE, 5);
+	gtk_box_pack_start (GTK_BOX (hbox2), button3, FALSE, FALSE, 5);
 
 	button2 = gtk_button_new_with_mnemonic (_("_Next"));
-	gtk_button_set_image (button2, gtk_image_new_from_stock(GTK_STOCK_GO_FORWARD, GTK_ICON_SIZE_BUTTON));
+	gtk_button_set_image (GTK_BUTTON (button2), gtk_image_new_from_stock(GTK_STOCK_GO_FORWARD, GTK_ICON_SIZE_BUTTON));
 	gtk_widget_show (button2);
-	gtk_box_pack_start ((GtkBox *)(hbox2), button2, FALSE, FALSE, 5);
+	gtk_box_pack_start (GTK_BOX (hbox2), button2, FALSE, FALSE, 5);
 
 	p->search_case_check = gtk_check_button_new_with_mnemonic (_("M_atch case"));
 	gtk_widget_show (p->search_case_check);
-	gtk_box_pack_start ((GtkBox *)(hbox2), p->search_case_check, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox2), p->search_case_check, FALSE, FALSE, 0);
 
 	p->search_matches_label = gtk_label_new ("");
 	gtk_widget_show (p->search_matches_label);
-	gtk_box_pack_start ((GtkBox *)(hbox2), p->search_matches_label, TRUE, TRUE, 0);
-	p->search_dialog = (GtkWidget *)hbox2;
+	gtk_box_pack_start (GTK_BOX (hbox2), p->search_matches_label, TRUE, TRUE, 0);
+	p->search_dialog = GTK_HBOX (hbox2);
 	
 	p->search_wrap = FALSE;
 
@@ -715,7 +715,7 @@ static void
 set_focus_cb (GtkWidget *window, GtkWidget *widget, EMFormatHTMLDisplay *efhd)
 {
 	struct _EMFormatHTMLDisplayPrivate *p = efhd->priv;
-	GtkWidget *sbar = p->search_dialog;
+	GtkWidget *sbar = GTK_WIDGET (p->search_dialog);
 	
 	while (widget != NULL && widget != sbar) {
 		widget = widget->parent;
@@ -761,15 +761,14 @@ em_format_html_display_search_with (EMFormatHTMLDisplay *efhd, char *word)
 	struct _EMFormatHTMLDisplayPrivate *p = efhd->priv;
 
 	if (p->search_dialog){
-               GtkWidget *toplevel;
                gtk_widget_show ( (GtkWidget *)(p->search_dialog));
 	       
 	       /* Set the query */
-	       gtk_entry_set_text ( (GtkWidget *) p->search_entry, word);
+	       gtk_entry_set_text (GTK_ENTRY (p->search_entry), word);
 	       gtk_widget_hide ( (GtkWidget *) p->search_entry_box);
 
 	       /* Trigger the search */
-	       gtk_signal_emit_by_name (p->search_entry, "activate", efhd);
+	       gtk_signal_emit_by_name (GTK_OBJECT (p->search_entry), "activate", efhd);
 	}
 }
 
@@ -779,7 +778,7 @@ em_format_html_display_search_close (EMFormatHTMLDisplay *efhd)
 	struct _EMFormatHTMLDisplayPrivate *p = efhd->priv;
 
 	if (p->search_dialog)
-		efhd_search_destroy(p->search_dialog, efhd);
+		efhd_search_destroy(GTK_WIDGET (p->search_dialog), efhd);
 }
 
 void
@@ -896,12 +895,13 @@ efhd_html_link_clicked (GtkHTML *html, const char *url, EMFormatHTMLDisplay *efh
 				((EMFormatHTML *) efhd)->header_wrap_flags |= EM_FORMAT_HTML_HEADER_CC;
 			else
 				((EMFormatHTML *) efhd)->header_wrap_flags &= ~EM_FORMAT_HTML_HEADER_CC;
-		else if (!strcmp (url, "##BCC##"))
+		else if (!strcmp (url, "##BCC##")) {
 			if (!(((EMFormatHTML *) efhd)->header_wrap_flags & EM_FORMAT_HTML_HEADER_BCC))
 				((EMFormatHTML *) efhd)->header_wrap_flags |= EM_FORMAT_HTML_HEADER_BCC;
 			else
 				((EMFormatHTML *) efhd)->header_wrap_flags &= ~EM_FORMAT_HTML_HEADER_BCC;
-		em_format_redraw((EMFormat *)efhd);     
+		}
+		em_format_redraw((EMFormat *)efhd);
 	} else
 	    g_signal_emit((GObject *)efhd, efhd_signals[EFHD_LINK_CLICKED], 0, url);
 }
@@ -1574,7 +1574,7 @@ efhd_drag_data_get(GtkWidget *w, GdkDragContext *drag, GtkSelectionData *data, g
 		/* Kludge around Nautilus requesting the same data many times */
 		uri = g_object_get_data((GObject *)w, "e-drag-uri");
 		if (uri) {
-			gtk_selection_data_set(data, data->target, 8, uri, strlen(uri));
+			gtk_selection_data_set(data, data->target, 8, (unsigned char *)uri, strlen(uri));
 			return;
 		}
 
@@ -1586,7 +1586,7 @@ efhd_drag_data_get(GtkWidget *w, GdkDragContext *drag, GtkSelectionData *data, g
 		g_free(path);
 		uri_crlf = g_strconcat(uri, "\r\n", NULL);
 		g_free(uri);
-		gtk_selection_data_set(data, data->target, 8, uri_crlf, strlen(uri_crlf));
+		gtk_selection_data_set(data, data->target, 8, (unsigned char *)uri_crlf, strlen(uri_crlf));
 		g_object_set_data_full((GObject *)w, "e-drag-uri", uri_crlf, g_free);
 		break;
 	default:
@@ -1983,7 +1983,7 @@ efhd_bonobo_object(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject *
 	persist = (Bonobo_PersistStream)Bonobo_Unknown_queryInterface(bonobo_widget_get_objref((BonoboWidget *)embedded),
 								      "IDL:Bonobo/PersistStream:1.0", &ev);
 	if (persist == CORBA_OBJECT_NIL) {
-		gtk_object_sink((GtkObject *)embedded);
+		g_object_ref_sink(embedded);
 		CORBA_exception_free(&ev);				
 		return FALSE;
 	}
@@ -2000,7 +2000,7 @@ efhd_bonobo_object(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject *
 	}
 	
 	/* ...convert the CamelStreamMem to a BonoboStreamMem... */
-	bstream = bonobo_stream_mem_create(cstream->buffer->data, cstream->buffer->len, TRUE, FALSE);
+	bstream = bonobo_stream_mem_create((char *)cstream->buffer->data, cstream->buffer->len, TRUE, FALSE);
 	camel_object_unref(cstream);
 	
 	/* ...and hydrate the PersistStream from the BonoboStream. */
@@ -2012,7 +2012,7 @@ efhd_bonobo_object(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject *
 	CORBA_Object_release(persist, &ev);
 	
 	if (ev._major != CORBA_NO_EXCEPTION) {
-		gtk_object_sink((GtkObject *)embedded);
+		g_object_ref_sink(embedded);
 		CORBA_exception_free(&ev);				
 		return FALSE;
 	}
@@ -2099,12 +2099,26 @@ attachment_bar_arrow_clicked(GtkWidget *w, EMFormatHTMLDisplay *efhd)
 }
 
 static void
-attachments_save_all_clicked(GtkWidget *w, EMFormatHTMLDisplay *efhd)
+attachments_save_all_clicked (GtkWidget *widget, EMFormatHTMLDisplay *efhd)
 {
 	GSList *attachment_parts;
+	guint n_attachment_parts;
 
-	attachment_parts = e_attachment_bar_get_parts(E_ATTACHMENT_BAR(efhd->priv->attachment_bar));
-	em_utils_save_parts(w, _("Select folder to save all attachments..."), attachment_parts);
+	attachment_parts = e_attachment_bar_get_parts (
+		E_ATTACHMENT_BAR (efhd->priv->attachment_bar));
+	n_attachment_parts = g_slist_length (attachment_parts);
+	g_return_if_fail (n_attachment_parts > 0);
+
+	if (n_attachment_parts == 1)
+		em_utils_save_part (
+			widget, _("Save attachment as"),
+			attachment_parts->data);
+	else
+		em_utils_save_parts (
+			widget, _("Select folder to save all attachments"),
+			attachment_parts);
+
+        g_slist_free (attachment_parts);
 }
 
 static void
@@ -2144,6 +2158,7 @@ efhd_bar_save_selected(EPopup *ep, EPopupItem *item, void *data)
 
 	parts = g_slist_reverse(parts);
 	em_utils_save_parts(efhd->priv->attachment_bar, _("Select folder to save selected attachments..."), parts);
+        g_slist_free (parts);
 
 	g_slist_foreach(attachment_parts, (GFunc)g_object_unref, NULL);
 	g_slist_free (attachment_parts);
@@ -2426,13 +2441,13 @@ efhd_format_attachment(EMFormat *emf, CamelStream *stream, CamelMimePart *part,
 static void 
 efhd_optional_button_show (GtkWidget *widget, GtkWidget *w)
 {
-	GtkWidget *label = g_object_get_data (widget, "text-label");
+	GtkWidget *label = g_object_get_data (G_OBJECT (widget), "text-label");
 	
 	if (GTK_WIDGET_VISIBLE (w)) {
 		gtk_widget_hide (w);
-		gtk_label_set_text_with_mnemonic (label, _("View _Unformatted"));
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _("View _Unformatted"));
 	} else {
-		gtk_label_set_text_with_mnemonic (label, _("Hide _Unformatted"));		
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (label), _("Hide _Unformatted"));		
 		gtk_widget_show (w);
 	}
 }
@@ -2447,20 +2462,11 @@ efhd_resize (GtkWidget *w, GtkAllocation *event, EMFormatHTML *efh)
 static gboolean
 efhd_attachment_optional(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject *pobject)
 {
-	EMFormatHTMLDisplay *efhd = (EMFormatHTMLDisplay *)efh;
-	EAttachment *new;
 	struct _attach_puri *info;
-	GtkWidget *hbox, *vbox, *w, *button, *mainbox, *scroll, *label, *img;
-	char *simple_type, *tmp, *new_file = NULL;
-	const char *file;
-	GdkPixbuf *pixbuf, *mini;
+	GtkWidget *hbox, *vbox, *button, *mainbox, *scroll, *label, *img;
 	AtkObject *a11y;
 	GtkTextView *view;
 	GtkTextBuffer *buffer;
-	GtkTargetEntry drag_types[] = {
-		{ NULL, 0, 0 },
-		{ "text/uri-list", 0, 1 },
-	};
 
 	/* FIXME: handle default shown case */
 	d(printf("adding attachment button/content for optional rendering\n"));
@@ -2476,11 +2482,11 @@ efhd_attachment_optional(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPOb
 	hbox = gtk_hbox_new (FALSE, 0);
 	img = e_icon_factory_get_image ("stock_show-all", E_ICON_SIZE_BUTTON);
 	label = gtk_label_new_with_mnemonic(_("View _Unformatted"));
-	g_object_set_data (button, "text-label", (gpointer)label);
+	g_object_set_data (G_OBJECT (button), "text-label", (gpointer)label);
 	gtk_box_pack_start ((GtkBox *)hbox, img, TRUE, TRUE, 2);
 	gtk_box_pack_start ((GtkBox *)hbox, label, TRUE, TRUE, 2);
 	gtk_widget_show_all (hbox);
-	gtk_container_add (button, hbox);
+	gtk_container_add (GTK_CONTAINER (button), GTK_WIDGET (hbox));
 	if (info->handle)
 		g_signal_connect(button, "clicked", G_CALLBACK(efhd_optional_button_show), scroll);
 	else {
@@ -2499,7 +2505,7 @@ efhd_attachment_optional(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPOb
 	gtk_box_pack_start ((GtkBox *)hbox, label, TRUE, TRUE, 2);
 	gtk_box_pack_start ((GtkBox *)hbox, gtk_arrow_new(GTK_ARROW_DOWN, GTK_SHADOW_NONE), TRUE, TRUE, 2);
 	gtk_widget_show_all (hbox);
-	gtk_container_add (button, hbox);
+	gtk_container_add (GTK_CONTAINER (button), GTK_WIDGET (hbox));
 	
 	a11y = gtk_widget_get_accessible (button);
 	atk_object_set_name (a11y, _("Attachment"));
@@ -2513,18 +2519,20 @@ efhd_attachment_optional(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPOb
 
 	gtk_box_pack_start((GtkBox *)vbox, mainbox, FALSE, FALSE, 6);
 
-	view = gtk_text_view_new ();
+	view = (GtkTextView *)gtk_text_view_new ();
 	gtk_text_view_set_editable (view, FALSE);
 	gtk_text_view_set_cursor_visible (view, FALSE);
 	buffer = gtk_text_view_get_buffer(view);
-	gtk_text_buffer_set_text (buffer, info->mstream->buffer->data, info->mstream->buffer->len);
+	gtk_text_buffer_set_text (buffer, (char *)info->mstream->buffer->data, info->mstream->buffer->len);
 	camel_object_unref(info->mstream);
 	info->mstream = NULL;
-	gtk_scrolled_window_set_policy (scroll, GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scroll),
+					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll), GTK_SHADOW_IN);
-	gtk_container_add (scroll, view);
+	gtk_container_add (GTK_CONTAINER (scroll), GTK_WIDGET (view));
 	gtk_box_pack_start((GtkBox *)vbox, scroll, TRUE, TRUE, 6);
-	gtk_widget_show (view);
+	gtk_widget_show (GTK_WIDGET(view));
+
 	gtk_widget_set_size_request (scroll, ((GtkWidget *)efh->html)->allocation.width-48, 250);
 	g_signal_connect (scroll, "size_allocate", G_CALLBACK(efhd_resize), efh);
 	gtk_widget_show (scroll);
@@ -2542,7 +2550,7 @@ efhd_attachment_optional(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPOb
 static void
 efhd_format_optional(EMFormat *emf, CamelStream *fstream, CamelMimePart *part, CamelStream *mstream)
 {
-	char *classid, *text, *html;
+	char *classid, *html;
 	struct _attach_puri *info;
 	CamelStream *stream = ((CamelStreamFilter *) fstream)->source;
 	
@@ -2553,7 +2561,7 @@ efhd_format_optional(EMFormat *emf, CamelStream *fstream, CamelMimePart *part, C
 	info->shown = FALSE;
 	info->snoop_mime_type = g_strdup("text/plain");
 	info->attachment = e_attachment_new_from_mime_part (info->puri.part);
-	info->mstream = mstream;
+	info->mstream = (CamelStreamMem *)mstream;
 	if (emf->valid) {
 		info->sign = emf->valid->sign.status;
 		info->encrypt = emf->valid->encrypt.status;
