@@ -449,8 +449,11 @@ static void emfh_gethttp(struct _EMFormatHTMLJob *job, int cancelled)
 {
 	CamelStream *cistream = NULL, *costream = NULL, *instream = NULL;
 	CamelURL *url;
-	ssize_t n, total = 0;
+	CamelContentType *content_type;
+	CamelHttpStream *tmp_stream;
+	ssize_t n, total = 0, pc_complete = 0, nread = 0;
 	char buffer[1500];
+	const char *length;
 
 	if (cancelled
 	    || (url = camel_url_new(job->u.uri, NULL)) == NULL)
@@ -481,6 +484,13 @@ static void emfh_gethttp(struct _EMFormatHTMLJob *job, int cancelled)
 		camel_http_stream_set_proxy((CamelHttpStream *)instream, proxy);
 		g_free(proxy);
 		camel_operation_start(NULL, _("Retrieving `%s'"), job->u.uri);
+		tmp_stream = (CamelHttpStream *)instream;
+		content_type = camel_http_stream_get_content_type(tmp_stream);
+		length = camel_header_raw_find(&tmp_stream->headers, "Content-Length", NULL);
+		d(printf("  Content-Length: %s\n", length));
+		if (length != NULL)
+			total = atoi(length);
+		camel_content_type_unref(content_type);
 	} else
 		camel_operation_start_transient(NULL, _("Retrieving `%s'"), job->u.uri);
 
@@ -496,8 +506,12 @@ static void emfh_gethttp(struct _EMFormatHTMLJob *job, int cancelled)
 		/* FIXME: progress reporting in percentage, can we get the length always?  do we care? */
 		n = camel_stream_read(instream, buffer, sizeof (buffer));
 		if (n > 0) {
-			camel_operation_progress_count(NULL, total);
-			total += n;
+			nread += n;
+			/* If we didn't get a valid Content-Length header, do not try to calculate percentage */
+			if (total != 0) {
+				pc_complete = ((nread * 100) / total);
+				camel_operation_progress(NULL, pc_complete);
+			}
 			d(printf("  read %d bytes\n", n));
 			if (costream && camel_stream_write(costream, buffer, n) == -1) {
 				camel_data_cache_remove(emfh_http_cache, EMFH_HTTP_CACHE_PATH, job->u.uri, NULL);
@@ -565,7 +579,7 @@ efh_url_requested(GtkHTML *html, const char *url, GtkHTMLStream *handle, EMForma
 		job = em_format_html_job_new(efh, emfh_gethttp, g_strdup(url));
 	} else if  (g_ascii_strncasecmp(url, "/", 1) == 0) {
 		char *data = NULL;
-		int length = 0;
+		guint length = 0;
 		gboolean status;
 		
 		status = g_file_get_contents (url, &data, &length, NULL);
@@ -767,7 +781,7 @@ efh_text_plain(EMFormatHTML *efh, CamelStream *stream, CamelMimePart *part, EMFo
    					"<div style=\"border: solid #%06x 1px; background-color: #%06x; padding: 10px;\">\n",
    					efh->frame_colour & 0xffffff, efh->content_colour & 0xffffff);
 			camel_stream_write_string(stream, "<tt>\n");
-			em_format_format_text((EMFormat *)efh, (CamelStream *)filtered_stream, newpart);
+			em_format_format_text((EMFormat *)efh, (CamelStream *)filtered_stream, (CamelDataWrapper *)newpart);
 			camel_stream_flush((CamelStream *)filtered_stream);
 			camel_stream_write_string(stream, "</tt>\n");
 			camel_stream_write_string(stream, "</div>\n");
@@ -807,7 +821,7 @@ efh_text_enriched(EMFormatHTML *efh, CamelStream *stream, CamelMimePart *part, E
 			     "<div style=\"border: solid #%06x 1px; background-color: #%06x; padding: 10px;\">\n",
 			     efh->frame_colour & 0xffffff, efh->content_colour & 0xffffff);
 
-	em_format_format_text((EMFormat *)efh, (CamelStream *)filtered_stream, part);
+	em_format_format_text((EMFormat *)efh, (CamelStream *)filtered_stream, (CamelDataWrapper *)part);
 	
 	camel_object_unref(filtered_stream);
 	camel_stream_write_string(stream, "</div>");
@@ -829,7 +843,7 @@ efh_write_text_html(EMFormat *emf, CamelStream *stream, EMFormatPURI *puri)
 		camel_data_wrapper_write_to_stream(dw, out);
 	camel_object_unref(out);
 #endif
-	em_format_format_text(emf, stream, puri->part);
+	em_format_format_text(emf, stream, (CamelDataWrapper *)puri->part);
 }
 
 static void
@@ -985,7 +999,7 @@ efh_message_deliverystatus(EMFormatHTML *efh, CamelStream *stream, CamelMimePart
 	camel_object_unref(html_filter);
 
 	camel_stream_write_string(stream, "<tt>\n");
-	em_format_format_text((EMFormat *)efh, (CamelStream *)filtered_stream, part);
+	em_format_format_text((EMFormat *)efh, (CamelStream *)filtered_stream, (CamelDataWrapper *)part);
 	camel_stream_flush((CamelStream *)filtered_stream);
 	camel_stream_write_string(stream, "</tt>\n");
 
@@ -1519,7 +1533,7 @@ efh_format_address (EMFormatHTML *efh, GString *out, struct _camel_header_addres
 				
 				g_string_append_printf (out, "%s &lt;", name);
 				/* rfc2368 for mailto syntax and url encoding extras */
-				if ((real = camel_header_encode_phrase (a->name))) {
+				if ((real = camel_header_encode_phrase ((unsigned char *)a->name))) {
 					mailaddr = g_strdup_printf("%s <%s>", real, a->v.addr);
 					g_free (real);
 					mailto = camel_url_encode (mailaddr, "?=&()");
@@ -1641,7 +1655,7 @@ efh_format_header(EMFormat *emf, CamelStream *stream, CamelMedium *part, struct
 		label = _(name);
 		
 		html = g_string_new("");
-		img = efh_format_address(efh, html, addrs, label);
+		img = efh_format_address(efh, html, addrs, (char *)label);
 		
 		if (img) {
 //			str_field = g_strdup_printf ("<table><tr><td valign=top>%s</td><td valign=top><b>%s:</b></td></tr></table>", img, label);
@@ -1748,7 +1762,9 @@ efh_format_headers(EMFormatHTML *efh, CamelStream *stream, CamelMedium *part)
 	CamelContentType *ct;
 	struct _camel_header_raw *header;
 	gboolean have_icon = FALSE;
-			
+	const char *photo_name = NULL;
+	CamelInternetAddress *cia = NULL;
+		
 	ct = camel_mime_part_get_content_type((CamelMimePart *)part);
 	charset = camel_content_type_param (ct, "charset");
 	charset = e_iconv_charset_name(charset);	
@@ -1777,6 +1793,10 @@ efh_format_headers(EMFormatHTML *efh, CamelStream *stream, CamelMedium *part)
 			mailer = !g_ascii_strcasecmp (h->name, "X-Evolution-Mailer");
 			
 			while (header) {
+
+				if (emf->show_photo && !photo_name && !g_ascii_strcasecmp (header->name, "From"))
+					photo_name = header->value;
+									
 				if (!mailer_shown && mailer && (!g_ascii_strcasecmp (header->name, "X-Mailer") ||
 					       !g_ascii_strcasecmp (header->name, "User-Agent") ||
 					       !g_ascii_strcasecmp (header->name, "X-Newsreader"))) {
@@ -1801,6 +1821,29 @@ efh_format_headers(EMFormatHTML *efh, CamelStream *stream, CamelMedium *part)
 	if (!efh->simple_headers) {
 		camel_stream_printf(stream, "</table></td>");
 
+		if (photo_name) {
+			char *classid;
+			CamelMimePart *photopart;
+		
+			cia = camel_internet_address_new();
+			camel_address_decode((CamelAddress *) cia, (const char *) photo_name);
+			photopart = em_utils_contact_photo (cia, emf->photo_local);
+
+			if (photopart) {
+				classid = g_strdup_printf("icon:///em-format-html/%s/photo/header",
+				emf->part_id->str);
+				camel_stream_printf(stream,
+					"<td align=\"right\" valign=\"top\"><img width=64 src=\"%s\"></td>",
+					classid);
+				em_format_add_puri(emf, sizeof(EMFormatPURI), classid,
+					photopart, efh_write_image);
+				camel_object_unref(photopart);
+
+				g_free(classid);
+			}
+			camel_object_unref(cia);
+		}
+
 		if (have_icon && efh->show_icon) {
 			GtkIconInfo *icon_info;
 			char *classid;
